Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1001)

Unified Diff: content/browser/browsing_data/browsing_data_filter_builder_impl.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/browsing_data/browsing_data_filter_builder_impl.cc
diff --git a/content/browser/browsing_data/browsing_data_filter_builder_impl.cc b/content/browser/browsing_data/browsing_data_filter_builder_impl.cc
index 18f93a6502f20c03abbb50a63e403741f2dd2988..4770f4f824eef71d24d9aa7c6b63cc18e555423a 100644
--- a/content/browser/browsing_data/browsing_data_filter_builder_impl.cc
+++ b/content/browser/browsing_data/browsing_data_filter_builder_impl.cc
@@ -133,12 +133,12 @@ void BrowsingDataFilterBuilderImpl::AddOrigin(const url::Origin& origin) {
DCHECK_LE(origins_.size(), 10U) << "OriginFilterBuilder is only suitable "
"for creating small filters.";
// By limiting the filter to non-unique origins, we can guarantee that
// origin1 < origin2 && origin1 > origin2 <=> origin1.isSameOrigin(origin2).
// This means that std::set::find() will use the same semantics for
// origin comparison as Origin::IsSameOriginWith(). Furthermore, this
// means that two filters are equal iff they are equal element-wise.
- DCHECK(!origin.unique()) << "Invalid origin passed into OriginFilter.";
+ DCHECK(!origin.opaque()) << "Invalid origin passed into OriginFilter.";
// TODO(msramek): All urls with file scheme currently map to the same
// origin. This is currently not a problem, but if it becomes one,
@@ -133,12 +133,12 @@ void BrowsingDataFilterBuilderImpl::AddOrigin(const url::Origin& origin) {
DCHECK_LE(origins_.size(), 10U) << "OriginFilterBuilder is only suitable "
"for creating small filters.";
- // By limiting the filter to non-unique origins, we can guarantee that
+ // By limiting the filter to non-opaque origins, we can guarantee that
// origin1 < origin2 && origin1 > origin2 <=> origin1.isSameOrigin(origin2).
// This means that std::set::find() will use the same semantics for

Powered by Google App Engine
This is Rietveld 408576698